==> outlayer-8.x-1.5.tar.gz: outlayer/src/OutlayerHook.php <==
<?php

namespace Drupal\outlayer;

use Drupal\Core\File\FileSystem;
use Drupal\Core\Template\Attribute;
use Drupal\blazy\Blazy;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides Outlayer utility methods for Drupal hooks.
 */
class OutlayerHook {

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystem
   */
  protected $fileSystem;

  /**
   * The outlayer manager service.
   *
   * @var \Drupal\outlayer\OutlayerManagerInterface
   */
  protected $manager;

  /**
   * The library info definition.
   *
   * @var array
   */
  protected $libraryInfoBuild;

  /**
   * Constructs a Outlayer object.
   *
   * @param \Drupal\Core\File\FileSystem $file_system
   *   The file system service.
   * @param \Drupal\outlayer\OutlayerManagerInterface $manager
   *   The outlayer manager service.
   */
  public function __construct(FileSystem $file_system, OutlayerManagerInterface $manager) {
    $this->fileSystem = $file_system;
    $this->manager = $manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('file_system'), $container->get('outlayer.manager'));
  }

  /**
   * Implements hook_library_info_build().
   */
  public function libraryInfoBuild() {
    if (!isset($this->libraryInfoBuild)) {
      $libraries = [];
      foreach (array_values(OutlayerDefault::extraLayouts()) as $id) {
        if ($library = Blazy::getLibrariesPath('isotope-' . $id)) {
          $filename = $id == 'packery' ? $id . '-mode.pkgd' : $id;
          $ext = is_file($library . '/' . $filename . '.min.js') ? 'min.js' : 'js';

          $libraries['isotope-' . $id]['js']['/' . $library . '/' . $filename . '.' . $ext] = ['weight' => -2];
          $libraries['isotope-' . $id]['dependencies'][] = 'outlayer/isotope';
        }
      }
      $this->libraryInfoBuild = $libraries;
    }

    return $this->libraryInfoBuild;
  }

  /**
   * Implements hook_library_info_alter().
   */
  public function libraryInfoAlter(&$libraries, $extension) {
    if ($extension === 'outlayer' && Blazy::getLibrariesPath('outlayer')) {
      // The main library.
      // @todo remove checks once the library has minified versions.
      if ($library = Blazy::getLibrariesPath('outlayer')) {
        foreach (['item', 'outlayer'] as $name) {
          $ext = is_file($library . '/' . $name . '.min.js') ? 'min.js' : 'js';
          $libraries['outlayer']['js']['/' . $library . '/' . $name . '.' . $ext] = ['weight' => -6];
        }
      }

      // Layouts based on outlayer library.
      foreach (['isotope', 'masonry', 'packery'] as $id) {
        // Composer based libraries suffixed with `-layout`.
        $library = Blazy::getLibrariesPath($id) ?: Blazy::getLibrariesPath($id . '-layout');
        if ($library) {
          foreach ($libraries[$id]['js'] as $uri => $info) {
            $basename = $this->fileSystem->basename($uri);
            // @todo when we do not use .pkgd.min.js, extract from sources:
            // @todo $library = $id == 'masonry' ? $library : $library . '/js';
            // @todo $library = strpos($uri, 'layout-modes') !== FALSE ? $library . '/layout-modes' : $library;
            // @todo $libraries[$id]['js']['/' . $library . '/' . $basename] = $info;
            $libraries[$id]['js']['/' . $library . '/dist/' . $basename] = $info;
          }
        }
      }

      // Isotope extra layouts prefixed with `isotope-`.
      foreach (OutlayerDefault::extraLayouts() as $id) {
        $filename = $id == 'packery' ? $id . '-mode.pkgd' : $id;

        if ($library = Blazy::getLibrariesPath('isotope-' . $id)) {
          $ext = is_file($library . '/' . $filename . '.min.js') ? 'min.js' : 'js';
          $libraries['isotope-' . $id]['js']['/' . $library . '/' . $filename . '.' . $ext] = ['weight' => -2];
        }
      }
    }
  }

  /**
   * Implements hook_config_schema_info_alter().
   */
  public function configSchemaInfoAlter(array &$definitions) {
    if (isset($definitions['outlayer_base'])) {
      // @todo replace with BlazyAlter post Blazy 2.0.
      Blazy::configSchemaInfoAlter($definitions, 'outlayer_base', OutlayerDefault::extendedSettings());
    }
  }

  /**
   * Returns common button markup.
   *
   * @todo use a themeable output.
   */
  public static function button(array $variables) {
    $title      = $variables['title'];
    $classes    = ['btn', 'button', 'button--outlayer'];
    $attributes = new Attribute();

    if (!empty($variables['filter'])) {
      $attributes->setAttribute('data-filter', $variables['filter']);
      $classes[] = 'btn-primary';
    }
    if (!empty($variables['sorter'])) {
      $attributes->setAttribute('data-sort-by', $variables['sorter']);
      $classes[] = 'btn-secondary';
    }

    $classes = array_merge($classes, $variables['classes']);
    $attributes->addClass($classes);
    $attributes->setAttribute('type', 'button');

    return [
      '#markup' => '<button' . $attributes . '>' . $title . '</button>',
      '#allowed_tags' => ['button', 'span'],
    ];
  }

}

==> outlayer-8.x-1.6-rc1.tar.gz: outlayer/src/OutlayerHook.php <==
<?php

namespace Drupal\outlayer;

use Drupal\Core\File\FileSystem;
use Drupal\Core\Template\Attribute;
use Drupal\blazy\Blazy;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides Outlayer utility methods for Drupal hooks.
 */
class OutlayerHook implements OutlayerHookInterface {

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystem
   */
  protected $fileSystem;

  /**
   * The outlayer manager service.
   *
   * @var \Drupal\outlayer\OutlayerManagerInterface
   */
  protected $manager;

  /**
   * The library info definition.
   *
   * @var array
   */
  protected $libraryInfoBuild;

  /**
   * Constructs a Outlayer object.
   *
   * @param \Drupal\Core\File\FileSystem $file_system
   *   The file system service.
   * @param \Drupal\outlayer\OutlayerManagerInterface $manager
   *   The outlayer manager service.
   */
  public function __construct(FileSystem $file_system, OutlayerManagerInterface $manager) {
    $this->fileSystem = $file_system;
    $this->manager = $manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('file_system'),
      $container->get('outlayer.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function button(array $variables): array {
    $title      = $variables['title'];
    $classes    = ['btn', 'button', 'button--outlayer'];
    $attributes = new Attribute();

    if (!empty($variables['filter'])) {
      $attributes->setAttribute('data-filter', $variables['filter']);
      $classes[] = 'btn-primary';
    }
    if (!empty($variables['sorter'])) {
      $attributes->setAttribute('data-sort-by', $variables['sorter']);
      $classes[] = 'btn-secondary';
    }

    $classes = array_merge($classes, $variables['classes']);
    $attributes->addClass($classes);
    $attributes->setAttribute('type', 'button');

    return [
      '#markup' => '<button' . $attributes . '>' . $title . '</button>',
      '#allowed_tags' => ['button', 'span'],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function configSchemaInfoAlter(array &$definitions): void {
    if (isset($definitions['outlayer_base'])) {
      // @todo replace with BlazyAlter post Blazy 2.0.
      Blazy::configSchemaInfoAlter($definitions, 'outlayer_base', OutlayerDefault::extendedSettings());
    }
  }

  /**
   * {@inheritdoc}
   */
  public function libraryInfoBuild(): array {
    if (!isset($this->libraryInfoBuild)) {
      $libraries = [];
      foreach (array_values(OutlayerDefault::extraLayouts()) as $id) {
        if ($library = Blazy::getLibrariesPath('isotope-' . $id)) {
          $filename = $id == 'packery' ? $id . '-mode.pkgd' : $id;
          $ext = is_file($library . '/' . $filename . '.min.js') ? 'min.js' : 'js';

          $libraries['isotope-' . $id]['js']['/' . $library . '/' . $filename . '.' . $ext] = ['weight' => -2];
          $libraries['isotope-' . $id]['dependencies'][] = 'outlayer/isotope';
        }
      }
      $this->libraryInfoBuild = $libraries;
    }

    return $this->libraryInfoBuild;
  }

  /**
   * {@inheritdoc}
   */
  public function libraryInfoAlter(array &$libraries, $extension): void {
    if ($extension === 'outlayer' && Blazy::getLibrariesPath('outlayer')) {
      // The main library.
      // @todo remove checks once the library has minified versions.
      if ($library = Blazy::getLibrariesPath('outlayer')) {
        foreach (['item', 'outlayer'] as $name) {
          $ext = is_file($library . '/' . $name . '.min.js') ? 'min.js' : 'js';
          $libraries['outlayer']['js']['/' . $library . '/' . $name . '.' . $ext] = ['weight' => -6];
        }
      }

      // Layouts based on outlayer library.
      foreach (['isotope', 'masonry', 'packery'] as $id) {
        // Composer based libraries suffixed with `-layout`.
        $library = Blazy::getLibrariesPath($id) ?: Blazy::getLibrariesPath($id . '-layout');
        if ($library) {
          foreach ($libraries[$id]['js'] as $uri => $info) {
            $basename = $this->fileSystem->basename($uri);
            // @todo when we do not use .pkgd.min.js, extract from sources:
            // @todo $library = $id == 'masonry' ? $library : $library . '/js';
            // @todo $library = strpos($uri, 'layout-modes') !== FALSE ? $library . '/layout-modes' : $library;
            // @todo $libraries[$id]['js']['/' . $library . '/' . $basename] = $info;
            $libraries[$id]['js']['/' . $library . '/dist/' . $basename] = $info;
          }
        }
      }

      // Isotope extra layouts prefixed with `isotope-`.
      foreach (OutlayerDefault::extraLayouts() as $id) {
        $filename = $id == 'packery' ? $id . '-mode.pkgd' : $id;

        if ($library = Blazy::getLibrariesPath('isotope-' . $id)) {
          $ext = is_file($library . '/' . $filename . '.min.js') ? 'min.js' : 'js';
          $libraries['isotope-' . $id]['js']['/' . $library . '/' . $filename . '.' . $ext] = ['weight' => -2];
        }
      }
    }
  }

}
